Author: shadowmaster
Date: Thu May 29 23:40:54 2008
New Revision: 26914

URL: http://svn.gna.org/viewcvs/wesnoth?rev=26914&view=rev
Log:
* Expose border_size map property to the world (const)

Modified:
    trunk/src/map.hpp

Modified: trunk/src/map.hpp
URL: 
http://svn.gna.org/viewcvs/wesnoth/trunk/src/map.hpp?rev=26914&r1=26913&r2=26914&view=diff
==============================================================================
--- trunk/src/map.hpp (original)
+++ trunk/src/map.hpp Thu May 29 23:40:54 2008
@@ -167,12 +167,17 @@
        //! Overlays another map onto this one at the given position.
        void overlay(const gamemap& m, const config& rules, const int x=0, 
const int y=0);
 
-       //! Effective dimensions of the map.
+       //! Effective map width.
        int w() const { return w_; }
+       //! Effective map height.
        int h() const { return h_; }
 
-       //! Real dimension of the map, including borders
+       //! Size of the map border.
+       int border_size() const { return border_size_; }
+
+       //! Real width of the map, including borders.
        int total_width()  const { return total_width_; }
+       //! Real height of the map, including borders
        int total_height() const { return total_height_; }
 
        const t_translation::t_terrain operator[](const gamemap::location& loc) 
const


_______________________________________________
Wesnoth-commits mailing list
[email protected]
https://mail.gna.org/listinfo/wesnoth-commits

Reply via email to